(******************************************************************************
 *  TxtAss                                                                    *
 ******************************************************************************)
unit AcTxtAssist;

(******************************************************************************
 * Interface                                                                  *
 ******************************************************************************)
interface

(******************************************************************************
 * Uses                                                                       *
 ******************************************************************************)
uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  AcProcDeclare;

(******************************************************************************
 *  TACTextAss                                                                *
 ******************************************************************************)
type
  TACTextAss = class(TComponent)
  private
    { Private declarations }
    FName     : String;  // Nome del file
    FProcFind : TACTextProcedureFind;
  protected
    { Protected declarations }
    Procedure SetFName (Nome:String);Virtual;
  public
    { Public declarations }
    Procedure CreateFile; // Crea il file vuoto per l'help
    Procedure Add(Titolo,Words,Termine:String;ID:Integer);
    Procedure Edit(Num:Integer;Titolo,Words,Termine:String;ID:Integer);
    Procedure Get(Num:Integer;Var Titolo,Words,Termine:String;Var ID:Integer);
    Function  RecordCount : Integer;
    Procedure FindWord(frase:String);
    Constructor Create(AOwner: TComponent); override;
  published
    { Published declarations }
    Property FileName : String Read FName Write SetFName;
    Property AfterReadEveryOne : TACTextProcedureFind Read FProcFind Write FProcFind;
  end;

(******************************************************************************
 * Implementation                                                             *
 ******************************************************************************)
implementation

(******************************************************************************
 * Uses                                                                       *
 ******************************************************************************)
uses AcGesTxt;


(******************************************************************************
 * Struttura TParoleAssist                                                    *
 ******************************************************************************)
type TParoleAssist = record
  Titolo     : String[200];   // Titolo dell'argomento
  HelpContID : Integer;       // HelpContextId
  Words      : String[200];   // Parole da usare per la ricerca
  Termine    : String[100];   // Elenco di termini che devono essere presenti
                              // obbligatoriamento per riconoscere la parola
End;


(******************************************************************************
 * SetFname                                                                   *
 *                                                                            *
 * Imposta il nome del file                                                   *
 ******************************************************************************)
Procedure TACTextAss.SetFName (Nome:String);
Begin
  FName := Nome;
End;

(******************************************************************************
 * CreateFile                                                                 *
 *                                                                            *
 * Crea un file per la guida vuoto                                            *
 ******************************************************************************)
Procedure TACTextAss.CreateFile;
Var H_file : Integer;
Begin
  if(FileName<>'') then
  begin
    H_File := FileCreate(Filename);
    If(H_File>0) Then FileClose(H_File);
  end;
End;


(******************************************************************************
 * Add                                                                        *
 *                                                                            *
 * Aggiunge nel file un record nuovo                                          *
 *                                                                            *
 * Nome            Descrizione                                                *
 * --------------- ---------------------------------------------------------- *
 * Desc            Descrizione                                                *
 * Words           Parole per la ricerca                                      *
 * ID              ID per riferimento all'help                                *
 ******************************************************************************)
Procedure TACTextAss.Add(Titolo,Words,Termine:String;ID:Integer);
Begin
  Edit(-1,Titolo,Words,Termine,ID);
End;

(******************************************************************************
 * RecordCount                                                                *
 *                                                                            *
 * Restituisce il numero di record                                            *
 ******************************************************************************)
Function TACTextAss.RecordCount:Integer;
Var H_File : Integer;
Begin
  if(FileName<>'') then
  begin
    H_File := FileOpen(Filename,fmOpenRead);
    If(H_File>0) Then
    Begin
      RecordCount:=(FileSeek(H_File,0,2) div Sizeof(TParoleAssist)) ;
      FileClose(H_File);
    End
    else RecordCount:=0;
    exit;
  end;
  RecordCount := 0;
End;


(******************************************************************************
 * Get                                                                        *
 *                                                                            *
 * Restituisce le informazioni sul record interessato                         *
 *                                                                            *
 * Nome            Descrizione                                                *
 * --------------- ---------------------------------------------------------- *
 * Num             Numero del record, i record iniziano con il numero 0       *
 * Desc            Descrizione                                                *
 * Words           Parole per la ricerca                                      *
 * ID              ID per riferimento all'help                                *
 ******************************************************************************)
Procedure TACTextAss.Get(Num:Integer;Var Titolo,Words,Termine:String;Var ID:Integer);
Var H_File : Integer;
    Rec : TParoleAssist;
Begin
  if(FileName<>'') then
  begin
    H_File := FileOpen(Filename,fmOpenReadWrite);
    If(H_File>0) Then
    Begin
      FileSeek(H_File,Num*Sizeof(TParoleAssist),0);
      FileRead(H_File,Rec,Sizeof(TParoleAssist));
      Titolo := Rec.Titolo;
      Words  := Rec.Words;
      ID     := Rec.HelpContID;
      Termine:= Rec.Termine;
      FileClose(H_File);
    End;
  end;

End;
(******************************************************************************
 * Add                                                                        *
 *                                                                            *
 * Edita o il record desiderato                                               *
 *                                                                            *
 * Nome            Descrizione                                                *
 * --------------- ---------------------------------------------------------- *
 * Num             Numero del record, i record iniziano con il numero 0       *
 * Desc            Descrizione                                                *
 * Words           Parole per la ricerca                                      *
 * ID              ID per riferimento all'help                                *
 ******************************************************************************)
Procedure TACTextAss.Edit(Num:Integer;Titolo,Words,Termine:String;ID:Integer);
Var H_File : Integer;
    Rec : TParoleAssist;
Begin
  if(FileName<>'') then
  begin
    H_File := FileOpen(Filename,fmOpenReadWrite);
    If(H_File>0) Then
    Begin

      if(num=-1) then FileSeek(H_File,0,2)
      else FileSeek(H_File,Num*Sizeof(TParoleAssist),0);
      Rec.Titolo     := Titolo;
      Rec.Words      := Words;
      Rec.Termine    := Termine;
      Rec.HelpContID := ID;
      FileWrite(H_File,Rec,Sizeof(TParoleAssist));
      FileClose(H_File);
    End;
  end;

End;

(******************************************************************************
 * FindWord                                                                   *
 *                                                                            *
 * Restituisce il numero di record                                            *
 *                                                                            *
 ******************************************************************************)
Procedure TACTextAss.FindWord(frase:String);
Var
   ID                   : Integer;
   Titolo,Words,Termine : String;
   Parole1              : TStringList;
   Parole2              : TStringList;
   C1,c2,c3             : Integer;
   Necessario           : Boolean;
   Uguali               : Integer;
Begin
  Parole1 := TStringList.Create;
  Parole2 := TStringList.Create;
  Parole1.add('sdssss');
  split_parole(Frase,Parole1);
  if (RecordCount>0) Then
  Begin
    For c1 := 0 to Recordcount-1 do
    begin
// Cerca se sono presenti le parole interessate
      Get(c1,Titolo,Words,Termine,ID);
      split_parole(Words,Parole2);
      Uguali := 0;
      for c2 := 0 to Parole1.Count - 1 do
      Begin
        for c3 := 0 to Parole2.Count - 1 do
        Begin
          if(Uppercase(Parole1.Strings[c2])=Uppercase(Parole2.Strings[c3])) Then
          Begin
            Inc(Uguali);
          End;
        End;
      End;
// Cerca se presente anche sotto forma di sotto stringa una delle parola
// "obbligatorie" per la ricerca
      Necessario := False;
      split_parole(Termine,Parole2);
      for c2 := 0 to Parole1.Count - 1 do
      Begin
        for c3 := 0 to Parole2.Count - 1 do
        Begin

          if (Pos(Uppercase(Parole2.Strings[c3]),
                  Uppercase(Parole1.Strings[c2])) > 0 ) Then
          Begin
            Necessario := True;
          End;
        End;
      End;

      if Assigned(AfterReadEveryOne) Then FProcFind(Self, ID, Titolo,
                                                    Words, Uguali, Necessario);
    end;
  End;
  Parole1.Free;
  Parole2.Free;

End;

(******************************************************************************
 * Create                                                                     *
 ******************************************************************************)
Constructor TACTextAss.Create(AOwner: TComponent);
Begin
  Inherited;
  FProcFind:= Nil;
End;



end.


